@@ -402,12 +402,16 @@ class Model:
         #.count()
 
     @classmethod
-    def _score(cls, obj):
+    def _score(cls, obj=None, **kwarg):
         ''' Override this function to "score" your values. By default, this
             function supports some numeric objects such as ``int``, ``float``,
             ``complex``, ``bool``; ``datetime``, ``date`` and ``time`` in module
             ``datetime``.
 
+        You provide either a single value via ``obj`` or a map of variable names
+        pointing to their value via ``kwarg``. If you provide ``obj`` then
+        ``kwarg`` is ignored.
+
         For ``str``s, this function turns them to lower case, then calculates
         their value by summing up all characters.
 
@@ -418,39 +422,54 @@ class Model:
         total seconds from ``datetime.min``. ``time``'s value is total seconds
         it holds.
 
-        This function returns ``0`` for unsupported types.
+        For unsupported types, their value is ``0``.
+
+        Returns:
+            If ``obj`` is not ``None``, returns its score. If ``kwarg`` is not
+            ``None``, returns a map of original variable names to their score.
+            If both parameters were not provided, returns ``0``.
         '''
 
-        _type = type(obj)
+        def __score(value):
+            '''Calculates score of ``value``.'''
 
-        if _type in [dict, set, list, bytes]:
-            return len(obj)
-        elif _type == datetime.datetime:
-            return (obj - datetime.datetime.min).total_seconds()
-        elif _type == datetime.date:
-            return (obj - datetime.date.min).total_seconds()
-        elif _type == datetime.time:
-            result = obj.hour * 60 * 60 + obj.minute * 60 + obj.second + \
-                     obj.microsecond / 1000
-            if obj.tzinfo:
-                result += obj.tzinfo.utcoffset(None).total_seconds()
-            return result
-        elif _type in [int, float]:
-            return obj
-        elif _type == bool:
-            return int(obj)
-        elif _type == str:
-            # We assume all strings take the same _MAX_STR_LEN length. So we
-            # append all strings with "virtual" characters to fit _MAX_STR_LEN.
-            # Every "virtual" character has a value of 0.
-            if not cls._STR_CASE_SENSITIVE:
-                obj = obj.lower()
-            result = 0
-            for i in range(0, len(obj)):
-                result += ord(obj[i]) * 10**(cls._MAX_STR_LEN - i)
-            return result
+            _type = type(value)
+            if _type in [dict, set, list, bytes]:
+                return len(value)
+            elif _type == datetime.datetime:
+                return (value - datetime.datetime.min).total_seconds()
+            elif _type == datetime.date:
+                return (value - datetime.date.min).total_seconds()
+            elif _type == datetime.time:
+                _ = value.hour * 60 * 60 + value.minute * 60 + value.second + \
+                    value.microsecond / 1000
+                if value.tzinfo:
+                    _ += value.tzinfo.utcoffset(None).total_seconds()
+                return _
+            elif _type in [int, float]:
+                return value
+            elif _type == bool:
+                return int(value)
+            elif _type == str:
+                # We assume all strings take the same _MAX_STR_LEN length. So we
+                # append all strings with "virtual" characters to fit
+                # _MAX_STR_LEN. Every "virtual" character has a value of 0.
+                if not cls._STR_CASE_SENSITIVE:
+                    value = value.lower()
+                result = 0
+                for i in range(0, len(value)):
+                    result += ord(value[i]) * 10**(cls._MAX_STR_LEN - i)
+                return result
 
-        return 0
+            return 0
+            #.__score()
+
+        if obj != None: return __score(obj)
+        if not kwarg: return 0
+
+        for name, value in kwarg.items():
+            kwarg[name] = __score(value)
+        return kwarg
         #._score()
 
     def __init__(self, __strict=True, **args):
